How skin options work - WeeWX 5.0
Author: Tom Keffer <tkeffer@gmail.com>

Skip to content

# Skin configuration options

The skin configuration options that control report behavior such as:

- how files and plots are generated
- how files and plots look
- how data are displayed
- how units are displayed
- which language is used

Options that control the behavior of a skin should be in the skin configuration file `skin.conf`.

Language-dependent labels and texts should be in the language files, located in a skin's `lang` directory.

UTF-8 is used throughout the skin configuration file, just as it is throughout the WeeWX configuration file.